|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r57878 - in sandbox/variadic_templates: boost/mpl boost/mpl/package libs/mpl/sandbox libs/mpl/test
From: cppljevans_at_[hidden]
Date: 2009-11-23 23:59:26
Author: cppljevans
Date: 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
New Revision: 57878
URL: http://svn.boost.org/trac/boost/changeset/57878
Log:
Used fold_assoc*<assoc_{left,right},,,> as replacement for fold{l,r}<,,,>
Added:
sandbox/variadic_templates/boost/mpl/fold_assoc_iter.hpp (contents, props changed)
sandbox/variadic_templates/boost/mpl/fold_assoc_pack.hpp (contents, props changed)
sandbox/variadic_templates/boost/mpl/fold_assoc_seq.hpp (contents, props changed)
Text files modified:
sandbox/variadic_templates/boost/mpl/fold.hpp | 13 +++++----
sandbox/variadic_templates/boost/mpl/iter_fold.hpp | 13 +++++----
sandbox/variadic_templates/boost/mpl/list.hpp | 7 +++--
sandbox/variadic_templates/boost/mpl/map.hpp | 13 +++++----
sandbox/variadic_templates/boost/mpl/package/package0.hpp | 50 ++++++++++++++++++++++++++++++++++++++++
sandbox/variadic_templates/boost/mpl/reverse_fold.hpp | 11 ++++----
sandbox/variadic_templates/boost/mpl/set.hpp | 13 +++++----
sandbox/variadic_templates/boost/mpl/vector.hpp | 10 ++++---
sandbox/variadic_templates/libs/mpl/sandbox/Jamfile | 49 +++++++++++++++++++++++++++++++++++++++
sandbox/variadic_templates/libs/mpl/test/Jamfile | 8 +++---
sandbox/variadic_templates/libs/mpl/test/vector.cpp | 4 +-
11 files changed, 149 insertions(+), 42 deletions(-)
Modified: sandbox/variadic_templates/boost/mpl/fold.hpp
==============================================================================
--- sandbox/variadic_templates/boost/mpl/fold.hpp (original)
+++ sandbox/variadic_templates/boost/mpl/fold.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -1,6 +1,6 @@
#ifndef BOOST_MPL_FOLD_HPP_VARIADIC_TEMPLATES
#define BOOST_MPL_FOLD_HPP_VARIADIC_TEMPLATES
-#include <boost/mpl/foldl_iter_if.hpp>
+#include <boost/mpl/fold_assoc_iter.hpp>
#include <boost/mpl/begin_end.hpp>
#include <boost/mpl/deref.hpp>
#include <boost/mpl/lambda.hpp>
@@ -16,17 +16,18 @@
fold
{
typedef
- typename foldl_iter_if
- < typename begin<Sequence>::type
- , typename end<Sequence>::type
- , State
+ typename fold_assoc_iter
+ < assoc_left
, typename lambda<OpStateVal>::type::template
apply
< arg<1>
, deref<arg<2> >
> //Changes OpStateVal to OpStateIter: (State,Iterator) -> State
//where Iterator is the type of iterator over Value's.
- >::type::fstate
+ , State
+ , typename begin<Sequence>::type
+ , typename end<Sequence>::type
+ >::type
type
;
};
Added: sandbox/variadic_templates/boost/mpl/fold_assoc_iter.hpp
==============================================================================
--- (empty file)
+++ sandbox/variadic_templates/boost/mpl/fold_assoc_iter.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -0,0 +1,135 @@
+#ifndef BOOST_MPL_FOLD_ASSOC_ITER_HPP_VARIADIC_TEMPLATES
+#define BOOST_MPL_FOLD_ASSOC_ITER_HPP_VARIADIC_TEMPLATES
+#include <boost/mpl/next.hpp>
+#include <boost/mpl/apply.hpp>
+#include <boost/mpl/op_assoc.hpp>
+namespace boost { namespace mpl {
+
+ template
+ < op_assoc OpAssoc
+ , typename OpBinary//Binary Operator
+ , typename State0 //intial State
+ , typename IterNow//start Iterator on Value's, i.e. deref<IterNow>::type is a "Value".
+ , typename IterEnd//end ValueIterator.
+ >
+ struct
+fold_assoc_iter
+/**@brief
+ * The same as:
+ * fold_assoc_pack<OpAssoc,OpBinaryTmpl,State0,Values...>
+ * (See fold_assoc_pack.hpp)
+ * where:
+ * Values... is the sequences of values obtained from
+ * deref'ing iterators in range, [InterNow,IterEnd), in order.
+ * OpBinaryTmpl is lambda<OpBinary>::type::apply
+ */
+;
+
+//Base Cases:
+// MAINTENANCE_NOTE:2009-11-12:L. Evans
+// It might seem there's no need for two specializations
+// of the base case since they both do the same thing; however,
+// without two specializations, g++ complains:
+// error: ambiguous class template instantiation for
+// 'boost::mpl::fold_assoc_iter<(boost::mpl::op_assoc)0u,...'
+//
+ template
+ < typename OpBinary
+ , typename State0
+ , typename IterEnd
+ >
+ struct
+fold_assoc_iter
+ < assoc_left
+ , OpBinary
+ , State0
+ , IterEnd
+ , IterEnd
+ >
+{
+ typedef
+ State0
+ type
+ ;
+};
+ template
+ < typename OpBinary
+ , typename State0
+ , typename IterEnd
+ >
+ struct
+fold_assoc_iter
+ < assoc_right
+ , OpBinary
+ , State0
+ , IterEnd
+ , IterEnd
+ >
+{
+ typedef
+ State0
+ type
+ ;
+};
+
+//Induction Cases:
+
+ template
+ < typename OpStateIter_State//metafun:(State,Iter) -> State
+ , typename State0
+ , typename IterNow
+ , typename IterEnd
+ >
+ struct
+fold_assoc_iter
+ < assoc_left
+ , OpStateIter_State
+ , State0
+ , IterNow
+ , IterEnd
+ >
+: fold_assoc_iter
+ < assoc_left
+ , OpStateIter_State
+ , typename apply
+ < OpStateIter_State
+ , State0
+ , IterNow
+ >::type
+ , typename next<IterNow>::type
+ , IterEnd
+ >
+{
+};
+
+ template
+ < typename OpIterState_State//metafun:(Iter,State) -> State
+ , typename State0
+ , typename IterNow
+ , typename IterEnd
+ >
+ struct
+fold_assoc_iter
+ < assoc_right
+ , OpIterState_State
+ , State0
+ , IterNow
+ , IterEnd
+ >
+: apply
+ < OpIterState_State
+ , IterNow
+ , typename fold_assoc_iter
+ < assoc_right
+ , OpIterState_State
+ , State0
+ , typename next<IterNow>::type
+ , IterEnd
+ >::type
+ >
+{
+};
+
+}}//exit boost::mpl namespace
+
+#endif //include guard
Added: sandbox/variadic_templates/boost/mpl/fold_assoc_pack.hpp
==============================================================================
--- (empty file)
+++ sandbox/variadic_templates/boost/mpl/fold_assoc_pack.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -0,0 +1,141 @@
+#ifndef BOOST_MPL_FOLD_ASSOC_PACK_HPP_VARIADIC_TEMPLATES
+#define BOOST_MPL_FOLD_ASSOC_PACK_HPP_VARIADIC_TEMPLATES
+// (C) Copyright Larry Evans 2009.
+//
+// Permission to copy, use, modify, sell and distribute this software
+// is granted provided this copyright notice appears in all copies.
+// This software is provided "as is" without express or implied
+// warranty, and with no claim as to its suitability for any purpose.
+//
+
+#include <boost/mpl/op_assoc.hpp>
+
+namespace boost { namespace mpl {
+
+ template
+ < op_assoc OpAssoc
+ , template<typename,typename>class OpBinary //metafun: (typename,typename) -> State
+ , typename State0 //initial State
+ , typename... Values
+ >
+ struct
+fold_assoc_pack
+/**@brief
+ * Apply OpStateValue_State to each element in Values...
+ * starting with intial State, State0.
+ * Associate the applications according to OpAssoc.
+ *
+ * Assume the following "aliases":
+ *
+ * alias real name
+ * ----- --------
+ * f OpBinary
+ * z State0
+ * x1,x2,x3 Values...
+ * f(x1,x2) OpBinary<x1,x2>::type
+ * r fold_assoc_pack<OpAssoc,OpBinary,State0,Values...>::type
+ * r == y boost::is_same<r,y>
+ *
+ * Then:
+ *
+ * If OpAssoc==assoc_left then:
+ *
+ * this template is like the haskell
+ * foldl described on p. 116 of:
+ *
+ * http://haskell.org/definition/haskell98-report.pdf
+ *
+ * IOW:
+ *
+ * r == f(f(f(z,x1),x2),x3)
+ *
+ * ElseIf OpAssoc==assoc_right then:
+ *
+ * this template is like the haskell
+ * foldr described on p. 117 of:
+ *
+ * http://haskell.org/definition/haskell98-report.pdf
+ *
+ * IOW:
+ *
+ * r == f(x1,f(x2,f(x3,z)))
+ *
+ */
+;
+
+//Base cases:
+
+ template
+ < op_assoc OpAssoc
+ , template<typename,typename>class OpBinary
+ , typename State0
+ >
+ struct
+fold_assoc_pack
+ < OpAssoc
+ , OpBinary
+ , State0
+ >
+{
+ typedef
+ State0
+ type
+ ;
+};
+
+//Induction cases:
+
+ template
+ < template<typename State,typename Value>class OpStateValue_State
+ , typename State0 //initial State
+ , typename Head
+ , typename... Tail
+ >
+ struct
+fold_assoc_pack
+ < assoc_left
+ , OpStateValue_State
+ , State0
+ , Head
+ , Tail...
+ >
+: fold_assoc_pack
+ < assoc_left
+ , OpStateValue_State
+ , typename OpStateValue_State
+ < State0
+ , Head
+ >::type
+ , Tail...
+ >
+{
+};
+
+ template
+ < template<typename Value,typename State>class OpValueState_State
+ , typename State0 //initial State
+ , typename Head
+ , typename... Tail
+ >
+ struct
+fold_assoc_pack
+ < assoc_right
+ , OpValueState_State
+ , State0
+ , Head
+ , Tail...
+ >
+: OpValueState_State
+ < Head
+ , typename fold_assoc_pack
+ < assoc_right
+ , OpValueState_State
+ , State0
+ , Tail...
+ >::type
+ >
+{
+};
+}}//exit boost::mpl namespace
+
+#endif //include guard
Added: sandbox/variadic_templates/boost/mpl/fold_assoc_seq.hpp
==============================================================================
--- (empty file)
+++ sandbox/variadic_templates/boost/mpl/fold_assoc_seq.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -0,0 +1,74 @@
+#ifndef BOOST_MPL_FOLD_ASSOC_HPP_VARIADIC_TEMPLATES
+#define BOOST_MPL_FOLD_ASSOC_HPP_VARIADIC_TEMPLATES
+#include <boost/mpl/fold_assoc_iter.hpp>
+#include <boost/mpl/begin_end.hpp>
+#include <boost/mpl/deref.hpp>
+#include <boost/mpl/lambda.hpp>
+
+namespace boost { namespace mpl {
+
+ template
+ < op_assoc OpAssoc
+ , typename OpBinary
+ , typename State
+ , typename Sequence
+ >
+ struct
+fold_assoc_seq
+;
+ template
+ < typename OpBinary
+ , typename State
+ , typename Sequence
+ >
+ struct
+fold_assoc_seq
+ < assoc_left
+ , OpBinary
+ , State
+ , Sequence
+ >
+: fold_assoc_iter
+ < assoc_left
+ , typename lambda<OpBinary>::type::template
+ apply
+ < arg<1>
+ , deref<arg<2> >
+ > //Changes OpStateVal to OpStateIter: (State,Iterator) -> State
+ //where Iterator is the type of iterator over Sequence.
+ , State
+ , typename begin<Sequence>::type
+ , typename end<Sequence>::type
+ >
+{
+};
+ template
+ < typename OpBinary
+ , typename State
+ , typename Sequence
+ >
+ struct
+fold_assoc_seq
+ < assoc_right
+ , OpBinary
+ , State
+ , Sequence
+ >
+: fold_assoc_iter
+ < assoc_right
+ , typename lambda<OpBinary>::type::template
+ apply
+ < deref<arg<1> >
+ , arg<2>
+ > //Changes OpValState to OpIterState: (Iterator,State) -> State
+ //where Iterator is the type of iterator over Sequence.
+ , State
+ , typename begin<Sequence>::type
+ , typename end<Sequence>::type
+ >
+{
+};
+
+}}//exit boost::mpl namespace
+
+#endif //include guard
Modified: sandbox/variadic_templates/boost/mpl/iter_fold.hpp
==============================================================================
--- sandbox/variadic_templates/boost/mpl/iter_fold.hpp (original)
+++ sandbox/variadic_templates/boost/mpl/iter_fold.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -1,6 +1,6 @@
#ifndef BOOST_MPL_ITER_FOLD_HPP_VARIADIC_TEMPLATES
#define BOOST_MPL_ITER_FOLD_HPP_VARIADIC_TEMPLATES
-#include <boost/mpl/foldl_iter.hpp>
+#include <boost/mpl/fold_assoc_iter.hpp>
#include <boost/mpl/begin_end.hpp>
namespace boost { namespace mpl {
@@ -8,15 +8,16 @@
template
< typename Sequence
, typename State
- , typename StateIterOp
+ , typename OpStateIter
>
struct
iter_fold
-: foldl_iter
- < typename begin<Sequence>::type
- , typename end<Sequence>::type
+: fold_assoc_iter
+ < assoc_left
+ , OpStateIter
, State
- , StateIterOp
+ , typename begin<Sequence>::type
+ , typename end<Sequence>::type
>
{
};
Modified: sandbox/variadic_templates/boost/mpl/list.hpp
==============================================================================
--- sandbox/variadic_templates/boost/mpl/list.hpp (original)
+++ sandbox/variadic_templates/boost/mpl/list.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -1,7 +1,7 @@
#ifndef BOOST_MPL_LIST_HPP_INCLUDED
#define BOOST_MPL_LIST_HPP_INCLUDED
#include <boost/mpl/list/list0.hpp>
-#include <boost/mpl/foldr_pack.hpp>
+#include <boost/mpl/fold_assoc_pack.hpp>
namespace boost
{
@@ -19,9 +19,10 @@
// one of the files:
// boost/mpl/list/aux_/preprocessed/plain/listN.hpp
// for some N in 10,20,...
- : foldr_pack
- < list0
+ : fold_assoc_pack
+ < assoc_right
, l_item_fold
+ , list0
, Values...
>::type
{
Modified: sandbox/variadic_templates/boost/mpl/map.hpp
==============================================================================
--- sandbox/variadic_templates/boost/mpl/map.hpp (original)
+++ sandbox/variadic_templates/boost/mpl/map.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -10,12 +10,12 @@
//
// See http://www.boost.org/libs/mpl for documentation.
-// $Source: /home/evansl/prog_dev/boost-svn/ro/boost-vrtmp/boost/mpl/RCS/map.hpp,v $
-// $Date: 2009/09/02 18:45:20 $
-// $Revision: 1.5 $
+// $Source: /home/evansl/prog_dev/boost-svn/ro/sandbox-rw/variadic_templates/boost/mpl/RCS/map.hpp,v $
+// $Date: 2009/11/23 14:43:13 $
+// $Revision: 1.7 $
#include <boost/mpl/map/map0.hpp>
-#include <boost/mpl/foldr_pack.hpp>
+#include <boost/mpl/fold_assoc_pack.hpp>
namespace boost
{
@@ -26,9 +26,10 @@
>
struct
map
- : foldr_pack
- < map0
+ : fold_assoc_pack
+ < assoc_right
, m_item_fold
+ , map0
, Values...
>::type
{
Modified: sandbox/variadic_templates/boost/mpl/package/package0.hpp
==============================================================================
--- sandbox/variadic_templates/boost/mpl/package/package0.hpp (original)
+++ sandbox/variadic_templates/boost/mpl/package/package0.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -14,6 +14,7 @@
#include <boost/mpl/at.hpp>
#include <boost/mpl/front.hpp>
#include <boost/mpl/push_front.hpp>
+#include <boost/mpl/pop_front.hpp>
#include <boost/mpl/push_back.hpp>
#include <boost/mpl/deref.hpp>
#include <boost/mpl/next.hpp>
@@ -155,6 +156,35 @@
template
< typename Package
+ >
+ struct
+ impl_pop_front
+ ;
+ template
+ < typename... Tail
+ , typename Head
+ , template
+ < typename...
+ >class Package
+ >
+ struct
+ impl_pop_front
+ < Package
+ < Head
+ , Tail...
+ >
+ >
+ {
+ typedef
+ Package
+ < Tail...
+ >
+ type
+ ;
+ };
+
+ template
+ < typename Package
, typename Tail
>
struct
@@ -354,6 +384,26 @@
<
>
struct
+ pop_front_impl
+ < aux::package_tag
+ >
+ {
+ template
+ < class Package
+ >
+ struct
+ apply
+ : variadic::impl_pop_front
+ < Package
+ >
+ {
+ };
+ };
+
+ template
+ <
+ >
+ struct
push_back_impl
< aux::package_tag
>
Modified: sandbox/variadic_templates/boost/mpl/reverse_fold.hpp
==============================================================================
--- sandbox/variadic_templates/boost/mpl/reverse_fold.hpp (original)
+++ sandbox/variadic_templates/boost/mpl/reverse_fold.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -1,6 +1,6 @@
#ifndef BOOST_MPL_REVERSE_FOLD_HPP_VARIADIC_TEMPLATES
#define BOOST_MPL_REVERSE_FOLD_HPP_VARIADIC_TEMPLATES
-#include <boost/mpl/foldr_iter.hpp>
+#include <boost/mpl/fold_assoc_iter.hpp>
#include <boost/mpl/begin_end.hpp>
#include <boost/mpl/deref.hpp>
#include <boost/mpl/lambda.hpp>
@@ -16,16 +16,17 @@
reverse_fold
{
typedef
- typename foldr_iter
- < typename begin<Sequence>::type
- , typename end<Sequence>::type
- , State
+ typename fold_assoc_iter
+ < assoc_right
, typename lambda<OpStateVal>::type::template
apply
< arg<2>
, deref<arg<1> >
> //Changes OpStateVal to OpIterState: (Iterator,State) -> State
//where Iterator is the type of iterator over Value's.
+ , State
+ , typename begin<Sequence>::type
+ , typename end<Sequence>::type
>::type
type
;
Modified: sandbox/variadic_templates/boost/mpl/set.hpp
==============================================================================
--- sandbox/variadic_templates/boost/mpl/set.hpp (original)
+++ sandbox/variadic_templates/boost/mpl/set.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -10,13 +10,13 @@
//
// See http://www.boost.org/libs/mpl for documentation.
-// $Source: /home/evansl/prog_dev/boost-svn/ro/boost-vrtmp/boost/mpl/RCS/set.hpp,v $
-// $Date: 2009/08/30 12:18:00 $
-// $Revision: 1.10 $
+// $Source: /home/evansl/prog_dev/boost-svn/ro/sandbox-rw/variadic_templates/boost/mpl/RCS/set.hpp,v $
+// $Date: 2009/11/23 14:47:01 $
+// $Revision: 1.13 $
#include <boost/mpl/aux_/value_wknd.hpp>
#include <boost/mpl/set/set0.hpp>
-#include <boost/mpl/foldr_pack.hpp>
+#include <boost/mpl/fold_assoc_pack.hpp>
namespace boost
{
@@ -28,9 +28,10 @@
>
struct
set
- : foldr_pack
- < set0
+ : fold_assoc_pack
+ < assoc_right
, s_item_fold
+ , set0
, Values...
>::type
//!
Modified: sandbox/variadic_templates/boost/mpl/vector.hpp
==============================================================================
--- sandbox/variadic_templates/libs/mpl/sandbox/Jamfile (original)
+++ sandbox/variadic_templates/libs/mpl/sandbox/Jamfile 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -15,3 +15,52 @@
unit-test tuple_non_recur.package_range_c.unit-test
: tuple_non_recur.package_range_c.cpp
;
+unit-test tupmap_indexed_test.unit-test
+ : tupmap_indexed_test.cpp
+ ;
+compile tupmap_indexed_test.cpp
+ :
+ : tupmap_indexed_test-compile
+ ;
+compile tuple_non_recur.cpp
+ :
+ : tuple_non_recur.compile
+ ;
+compile decltype.cpp
+ :
+ : decltype.compile
+ ;
+unit-test tuple_non_recur.unit-test
+ : tuple_non_recur.cpp
+ ;
+compile-fail tupmap_indexed_test.cpp
+ : <define>MAP_FACE_DUPKEY
+ : tupmap_indexed_test-MAP_FACE_DUPKEY
+ ;
+compile package_test.cpp
+ :
+ ;
+compile package_c_test.cpp
+ :
+ ;
+compile vector_c_test.cpp
+ :
+ ;
+compile fold_test.cpp
+ :
+ ;
+compile fold_c_test.cpp
+ :
+ ;
+compile cons_inherit_check_test.cpp
+ :
+ ;
+compile curry_map_index_test.cpp
+ :
+ ;
+compile-fail package_c_ice.cpp
+ :
+ ;
+#cpreproc test.cpreproc
+# : test.cpp
+# ;
Modified: sandbox/variadic_templates/libs/mpl/test/Jamfile
==============================================================================
--- sandbox/variadic_templates/libs/mpl/test/Jamfile (original)
+++ sandbox/variadic_templates/libs/mpl/test/Jamfile 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -5,7 +5,8 @@
compile aux_/preprocessor/is_seq.cpp ;
compile aux_/preprocessor/token_equal.cpp ;
- compile advance.cpp ;
+ compile test.cpp : : test.compile ;
+ compile advance.cpp : : advance.compile ;
compile always.cpp ;
compile apply.cpp ;
compile apply_wrap.cpp ;
@@ -20,7 +21,7 @@
compile comparison.cpp ;
compile contains.cpp ;
compile copy.cpp ;
- compile copy_if.cpp ;
+ compile copy_if.cpp : : copy_if.compile ;
compile count.cpp ;
compile count_if.cpp ;
compile deque.cpp ;
@@ -34,7 +35,7 @@
compile find.cpp ;
compile find_if.cpp ;
compile fold.cpp ;
- compile foldr_pack.cpp ;
+ compile fold_assoc_pack.cpp ;
run for_each.cpp ;
compile front.cpp ;
@@ -47,7 +48,6 @@
compile insert.cpp ;
compile insert_range.cpp ;
run int.cpp ;
- compile int.cpp : : int.compile ;
run integral_c.cpp : : : <toolset>vacpp:<cxxflags>-qchars=signed ;
compile is_placeholder.cpp ;
compile is_sequence.cpp ;
Modified: sandbox/variadic_templates/libs/mpl/test/vector.cpp
==============================================================================
--- sandbox/variadic_templates/libs/mpl/test/vector.cpp (original)
+++ sandbox/variadic_templates/libs/mpl/test/vector.cpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -8,8 +8,8 @@
// See http://www.boost.org/libs/mpl for documentation.
// $Id$
-// $Date: 2009/03/24 04:20:21 $
-// $Revision: 1.2 $
+// $Date: 2009/08/30 00:09:25 $
+// $Revision: 1.7 $
#include <boost/mpl/vector.hpp>
#include <boost/mpl/equal.hpp>
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/variadic_templates/boost/mpl/vector.hpp (original)
+++ sandbox/variadic_templates/boost/mpl/vector.hpp 2009-11-23 23:59:25 EST (Mon, 23 Nov 2009)
@@ -7,7 +7,7 @@
//! indirectly #includes vector_fwd.hpp.
//!
#include <boost/mpl/vector/vector0.hpp>
-#include <boost/mpl/foldr_pack.hpp>
+#include <boost/mpl/fold_assoc_pack.hpp>
namespace boost
{
@@ -19,9 +19,10 @@
>
struct
vector
- : foldr_pack
- < vector0
+ : fold_assoc_pack
+ < assoc_right
, v_item_fold
+ , vector0
, Values...
>::type
//!
@@ -36,7 +37,8 @@
//! WHAT:
//! 1) Instead of adding items from the tail, items are added from
//! head.
//! 2) foldr_pack is used instead of recursive call of vector.
//! WHY:
//! 1) The variadic template compiler doesn't allow parameter
//! packs to be followed by anything else (designated here as the
@@ -36,7 +37,8 @@
//! 1) Instead of adding items from the tail, items are added from
//! head.
-//! 2) foldr_pack is used instead of recursive call of vector.
+//! 2) fold_assoc_pack<assoc_right,,,> is used instead of
+//! recursive call of vector.
//! WHY:
//! 1) The variadic template compiler doesn't allow parameter
Modified: sandbox/variadic_templates/libs/mpl/sandbox/Jamfile
==============================================================================